## Docs Base

This is the documentation website that will be used as a base for Robyn and Starfyre docs.

## Setup

1. Clone this repo
2. Run `npm install`
3. Run `npm run dev`
4. Open `http://localhost:3000` in your browser

